@@ -20,9 +20,18 @@
 OpenStack Client interface. Handles the REST calls and responses.
 """
 
+import copy
+import errno
+import functools
+import glob
+import hashlib
 import logging
+import os
+import re
 import time
 
+from keystoneclient import adapter
+from oslo.utils import netutils
 import requests
 from requests import adapters
 
@@ -39,17 +48,127 @@ from novaclient import service_catalog
 from novaclient import utils
 
 
-_ADAPTERS = {}
+class _ClientConnectionPool(object):
+
+    def __init__(self):
+        self._adapters = {}
+
+    def get(self, url):
+        """
+        Store and reuse HTTP adapters per Service URL.
+        """
+        if url not in self._adapters:
+            self._adapters[url] = adapters.HTTPAdapter()
+
+        return self._adapters[url]
 
 
-def _adapter_pool(url):
+class CompletionCache(object):
+    """The completion cache is how we support tab-completion with novaclient.
+
+    The `Manager` writes object IDs and Human-IDs to the completion-cache on
+    object-show, object-list, and object-create calls.
+
+    The `nova.bash_completion` script then uses these files to provide the
+    actual tab-completion.
+
+    The cache directory layout is:
+
+        ~/.novaclient/
+            <hash-of-endpoint-and-username>/
+                <resource>-id-cache
+                <resource>-human-id-cache
     """
-    Store and reuse HTTP adapters per Service URL.
-    """
-    if url not in _ADAPTERS:
-        _ADAPTERS[url] = adapters.HTTPAdapter()
+    def __init__(self, username, auth_url, attributes=('id', 'human_id')):
+        self.directory = self._make_directory_name(username, auth_url)
+        self.attributes = attributes
 
-    return _ADAPTERS[url]
+    def _make_directory_name(self, username, auth_url):
+        """Creates a unique directory name based on the auth_url and username
+        of the current user.
+        """
+        uniqifier = hashlib.md5(username.encode('utf-8') +
+                                auth_url.encode('utf-8')).hexdigest()
+        base_dir = utils.env('NOVACLIENT_UUID_CACHE_DIR',
+                             default="~/.novaclient")
+        return os.path.expanduser(os.path.join(base_dir, uniqifier))
+
+    def _prepare_directory(self):
+        try:
+            os.makedirs(self.directory, 0o755)
+        except OSError:
+            # NOTE(kiall): This is typically either permission denied while
+            #              attempting to create the directory, or the
+            #              directory already exists. Either way, don't
+            #              fail.
+            pass
+
+    def clear_class(self, obj_class):
+        self._prepare_directory()
+
+        resource = obj_class.__name__.lower()
+        resource_glob = os.path.join(self.directory, "%s-*-cache" % resource)
+
+        for filename in glob.iglob(resource_glob):
+            try:
+                os.unlink(filename)
+            except OSError as e:
+                if e.errno != errno.ENOENT:
+                    raise
+
+    def _write_attribute(self, resource, attribute, value):
+        self._prepare_directory()
+
+        filename = "%s-%s-cache" % (resource, attribute.replace('_', '-'))
+        path = os.path.join(self.directory, filename)
+
+        with open(path, 'a') as f:
+            f.write("%s\n" % value)
+
+    def write_object(self, obj):
+        resource = obj.__class__.__name__.lower()
+
+        for attribute in self.attributes:
+            value = getattr(obj, attribute, None)
+            if value:
+                self._write_attribute(resource, attribute, value)
+
+
+class SessionClient(adapter.LegacyJsonAdapter):
+
+    def request(self, url, method, **kwargs):
+        # NOTE(jamielennox): The standard call raises errors from
+        # keystoneclient, where we need to raise the novaclient errors.
+        raise_exc = kwargs.pop('raise_exc', True)
+        resp, body = super(SessionClient, self).request(url,
+                                                        method,
+                                                        raise_exc=False,
+                                                        **kwargs)
+
+        if raise_exc and resp.status_code >= 400:
+            raise exceptions.from_response(resp, body, url, method)
+
+        return resp, body
+
+
+def _original_only(f):
+    """Indicates and enforces that this function can only be used if we are
+    using the original HTTPClient object.
+
+    We use this to specify that if you use the newer Session HTTP client then
+    you are aware that the way you use your client has been updated and certain
+    functions are no longer allowed to be used.
+    """
+    @functools.wraps(f)
+    def wrapper(self, *args, **kwargs):
+        if isinstance(self.client, SessionClient):
+            msg = ('This call is no longer available. The operation should '
+                   'be performed on the session object instead.')
+            raise exceptions.InvalidUsage(msg)
+
+        return f(self, *args, **kwargs)
+
+    return wrapper
 
 
 class HTTPClient(object):
@@ -64,12 +183,17 @@ class HTTPClient(object):
                  os_cache=False, no_cache=True,
                  http_log_debug=False, auth_system='keystone',
                  auth_plugin=None, auth_token=None,
-                 cacert=None, tenant_id=None):
+                 cacert=None, tenant_id=None, user_id=None,
+                 connection_pool=False):
         self.user = user
+        self.user_id = user_id
         self.password = password
         self.projectid = projectid
         self.tenant_id = tenant_id
 
+        self._connection_pool = (_ClientConnectionPool()
+                                if connection_pool else None)
+
         # This will be called by #_get_password if self.password is None.
         # EG if a password can only be obtained by prompting the user, but a
         # token is available, you don't want to prompt until the token has
@@ -83,7 +207,7 @@ class HTTPClient(object):
             auth_url = auth_plugin.get_auth_url()
             if not auth_url:
                 raise exceptions.EndpointNotFound()
-        self.auth_url = auth_url.rstrip('/')
+        self.auth_url = auth_url.rstrip('/') if auth_url else auth_url
         self.version = 'v1.1'
         self.region_name = region_name
         self.endpoint_type = endpoint_type
@@ -91,7 +215,7 @@ class HTTPClient(object):
         self.service_name = service_name
         self.volume_service_name = volume_service_name
         self.timings = timings
-        self.bypass_url = bypass_url
+        self.bypass_url = bypass_url.rstrip('/') if bypass_url else bypass_url
         self.os_cache = os_cache or not no_cache
         self.http_log_debug = http_log_debug
         if timeout is not None:
@@ -118,8 +242,8 @@ class HTTPClient(object):
 
         self.auth_system = auth_system
         self.auth_plugin = auth_plugin
+        self._session = None
         self._current_url = None
-        self._http = None
         self._logger = logging.getLogger(__name__)
 
         if self.http_log_debug and not self._logger.handlers:
@@ -152,6 +276,42 @@ class HTTPClient(object):
     def reset_timings(self):
         self.times = []
 
+    def _redact(self, target, path, text=None):
+        """Replace the value of a key in `target`.
+
+        The key can be at the top level by specifying a list with a single
+        key as the path. Nested dictionaries are also supported by passing a
+        list of keys to be navigated to find the one that should be replaced.
+        In this case the last one is the one that will be replaced.
+
+        :param dict target: the dictionary that may have a key to be redacted;
+                            modified in place
+        :param list path: a list representing the nested structure in `target`
+                          that should be redacted; modified in place
+        :param string text: optional text to use as a replacement for the
+                            redacted key. if text is not specified, the
+                            default text will be sha1 hash of the value being
+                            redacted
+        """
+
+        key = path.pop()
+
+        # move to the most nested dict
+        for p in path:
+            try:
+                target = target[p]
+            except KeyError:
+                return
+
+        if key in target:
+            if text:
+                target[key] = text
+            else:
+                # because in python3 byte string handling is ... ug
+                value = target[key].encode('utf-8')
+                sha1sum = hashlib.sha1(value)
+                target[key] = "{SHA1}%s" % sha1sum.hexdigest()
+
     def http_log_req(self, method, url, kwargs):
         if not self.http_log_debug:
             return
@@ -164,35 +324,66 @@ class HTTPClient(object):
         string_parts.append(" '%s'" % url)
         string_parts.append(' -X %s' % method)
 
-        for element in kwargs['headers']:
-            header = ' -H "%s: %s"' % (element, kwargs['headers'][element])
+        headers = copy.deepcopy(kwargs['headers'])
+        self._redact(headers, ['X-Auth-Token'])
+        # because dict ordering changes from 2 to 3
+        keys = sorted(headers.keys())
+        for name in keys:
+            value = headers[name]
+            header = ' -H "%s: %s"' % (name, value)
             string_parts.append(header)
 
         if 'data' in kwargs:
-            string_parts.append(" -d '%s'" % (kwargs['data']))
-        self._logger.debug("\nREQ: %s\n" % "".join(string_parts))
+            data = json.loads(kwargs['data'])
+            self._redact(data, ['auth', 'passwordCredentials', 'password'])
+            string_parts.append(" -d '%s'" % json.dumps(data))
+        self._logger.debug("REQ: %s" % "".join(string_parts))
 
     def http_log_resp(self, resp):
         if not self.http_log_debug:
             return
-        self._logger.debug(_("RESP: [%(status)s] %(headers)s\nRESP BODY: "
-                             "%(text)s\n"), {'status': resp.status_code,
-                                             'headers': resp.headers,
-                                             'text': resp.text})
 
-    def http(self, url):
-        magic_tuple = parse.urlsplit(url)
-        scheme, netloc, path, query, frag = magic_tuple
-        service_url = '%s://%s' % (scheme, netloc)
-        if self._current_url != service_url:
-            # Invalidate Session object in case the url is somehow changed
-            if self._http:
-                self._http.close()
-            self._current_url = service_url
-            self._logger.debug("New session created for: (%s)" % service_url)
-            self._http = requests.Session()
-            self._http.mount(service_url, _adapter_pool(service_url))
-        return self._http
+        if resp.text and resp.status_code != 400:
+            try:
+                body = json.loads(resp.text)
+                self._redact(body, ['access', 'token', 'id'])
+            except ValueError:
+                body = None
+        else:
+            body = None
+
+        self._logger.debug("RESP: [%(status)s] %(headers)s\nRESP BODY: "
+                           "%(text)s\n", {'status': resp.status_code,
+                                          'headers': resp.headers,
+                                          'text': json.dumps(body)})
+
+    def open_session(self):
+        if not self._connection_pool:
+            self._session = requests.Session()
+
+    def close_session(self):
+        if self._session and not self._connection_pool:
+            self._session.close()
+            self._session = None
+
+    def _get_session(self, url):
+        if self._connection_pool:
+            magic_tuple = parse.urlsplit(url)
+            scheme, netloc, path, query, frag = magic_tuple
+            service_url = '%s://%s' % (scheme, netloc)
+            if self._current_url != service_url:
+                # Invalidate Session object in case the url is somehow changed
+                if self._session:
+                    self._session.close()
+                self._current_url = service_url
+                self._logger.debug(
+                        "New session created for: (%s)" % service_url)
+                self._session = requests.Session()
+                self._session.mount(service_url,
+                        self._connection_pool.get(service_url))
+            return self._session
+        elif self._session:
+            return self._session
 
     def request(self, url, method, **kwargs):
         kwargs.setdefault('headers', kwargs.get('headers', {}))
@@ -207,7 +398,13 @@ class HTTPClient(object):
         kwargs['verify'] = self.verify_cert
 
         self.http_log_req(method, url, kwargs)
-        resp = self.http(url).request(
+
+        request_func = requests.request
+        session = self._get_session(url)
+        if session:
+            request_func = session.request
+
+        resp = request_func(
             method,
             url,
             **kwargs)
@@ -247,6 +444,15 @@ class HTTPClient(object):
     def _cs_request(self, url, method, **kwargs):
         if not self.management_url:
             self.authenticate()
+        if url is None:
+            # To get API version information, it is necessary to GET
+            # a nova endpoint directly without "v2/<tenant-id>".
+            magic_tuple = parse.urlsplit(self.management_url)
+            scheme, netloc, path, query, frag = magic_tuple
+            path = re.sub(r'v[1-9]/[a-z0-9]+$', '', path)
+            url = parse.urlunsplit((scheme, netloc, path, None, None))
+        else:
+            url = self.management_url + url
 
         # Perform the request once. If we get a 401 back then it
         # might be because the auth token expired, so try to
@@ -256,8 +462,7 @@ class HTTPClient(object):
             if self.projectid:
                 kwargs['headers']['X-Auth-Project-Id'] = self.projectid
 
-            resp, body = self._time_request(self.management_url + url, method,
-                                            **kwargs)
+            resp, body = self._time_request(url, method, **kwargs)
             return resp, body
         except exceptions.Unauthorized as e:
             try:
@@ -268,8 +473,7 @@ class HTTPClient(object):
                 self.keyring_saved = False
                 self.authenticate()
                 kwargs['headers']['X-Auth-Token'] = self.auth_token
-                resp, body = self._time_request(self.management_url + url,
-                                                method, **kwargs)
+                resp, body = self._time_request(url, method, **kwargs)
                 return resp, body
             except exceptions.Unauthorized:
                 raise e
@@ -347,14 +551,14 @@ class HTTPClient(object):
         # GET ...:5001/v2.0/tokens/#####/endpoints
         url = '/'.join([url, 'tokens', '%s?belongsTo=%s'
                         % (self.proxy_token, self.proxy_tenant_id)])
-        self._logger.debug(_("Using Endpoint URL: %s") % url)
+        self._logger.debug("Using Endpoint URL: %s" % url)
         resp, body = self._time_request(
             url, "GET", headers={'X-Auth-Token': self.auth_token})
         return self._extract_service_catalog(url, resp, body,
                                              extract_token=False)
 
     def authenticate(self):
-        magic_tuple = parse.urlsplit(self.auth_url)
+        magic_tuple = netutils.urlsplit(self.auth_url)
         scheme, netloc, path, query, frag = magic_tuple
         port = magic_tuple.port
         if port is None:
@@ -456,6 +660,10 @@ class HTTPClient(object):
         if self.auth_token:
             body = {"auth": {
                     "token": {"id": self.auth_token}}}
+        elif self.user_id:
+            body = {"auth": {
+                    "passwordCredentials": {"userId": self.user_id,
+                                            "password": self._get_password()}}}
         else:
             body = {"auth": {
                     "passwordCredentials": {"username": self.user,
@@ -484,6 +692,57 @@ class HTTPClient(object):
         return self._extract_service_catalog(url, resp, respbody)
 
 
+def _construct_http_client(username=None, password=None, project_id=None,
+                           auth_url=None, insecure=False, timeout=None,
+                           proxy_tenant_id=None, proxy_token=None,
+                           region_name=None, endpoint_type='publicURL',
+                           extensions=None, service_type='compute',
+                           service_name=None, volume_service_name=None,
+                           timings=False, bypass_url=None, os_cache=False,
+                           no_cache=True, http_log_debug=False,
+                           auth_system='keystone', auth_plugin=None,
+                           auth_token=None, cacert=None, tenant_id=None,
+                           user_id=None, connection_pool=False, session=None,
+                           auth=None, user_agent='python-novaclient',
+                           **kwargs):
+    if session:
+        return SessionClient(session=session,
+                             auth=auth,
+                             interface=endpoint_type,
+                             service_type=service_type,
+                             region_name=region_name,
+                             service_name=service_name,
+                             user_agent=user_agent,
+                             **kwargs)
+    else:
+        # FIXME(jamielennox): username and password are now optional. Need
+        # to test that they were provided in this mode.
+        return HTTPClient(username,
+                          password,
+                          user_id=user_id,
+                          projectid=project_id,
+                          tenant_id=tenant_id,
+                          auth_url=auth_url,
+                          auth_token=auth_token,
+                          insecure=insecure,
+                          timeout=timeout,
+                          auth_system=auth_system,
+                          auth_plugin=auth_plugin,
+                          proxy_token=proxy_token,
+                          proxy_tenant_id=proxy_tenant_id,
+                          region_name=region_name,
+                          endpoint_type=endpoint_type,
+                          service_type=service_type,
+                          service_name=service_name,
+                          volume_service_name=volume_service_name,
+                          timings=timings,
+                          bypass_url=bypass_url,
+                          os_cache=os_cache,
+                          http_log_debug=http_log_debug,
+                          cacert=cacert,
+                          connection_pool=connection_pool)
+
+
 def get_client_class(version):
     version_map = {
         '1.1': 'novaclient.v1_1.client.Client',
