@@ -44,6 +44,32 @@ unknown_error_response = utils.TestResponse({
 })
 unknown_error_mock_request = mock.Mock(return_value=unknown_error_response)
 
+retry_after_response = utils.TestResponse({
+    "status_code": 413,
+    "text": '',
+    "headers": {
+        "retry-after": "5"
+    },
+})
+retry_after_mock_request = mock.Mock(return_value=retry_after_response)
+
+retry_after_no_headers_response = utils.TestResponse({
+    "status_code": 413,
+    "text": '',
+})
+retry_after_no_headers_mock_request = mock.Mock(
+    return_value=retry_after_no_headers_response)
+
+retry_after_non_supporting_response = utils.TestResponse({
+    "status_code": 403,
+    "text": '',
+    "headers": {
+        "retry-after": "5"
+    },
+})
+retry_after_non_supporting_mock_request = mock.Mock(
+    return_value=retry_after_non_supporting_response)
+
 
 def get_client():
     cl = client.HTTPClient("username", "password",
@@ -79,7 +105,7 @@ class ClientTest(utils.TestCase):
                 headers=headers,
                 **self.TEST_REQUEST_BASE)
             # Automatic JSON parsing
-            self.assertEqual(body, {"hi": "there"})
+            self.assertEqual({"hi": "there"}, body)
 
         test_get_call()
 
@@ -136,11 +162,11 @@ class ClientTest(utils.TestCase):
     def test_client_logger(self):
         cl1 = client.HTTPClient("username", "password", "project_id",
                                 "auth_test", http_log_debug=True)
-        self.assertEqual(len(cl1._logger.handlers), 1)
+        self.assertEqual(1, len(cl1._logger.handlers))
 
         cl2 = client.HTTPClient("username", "password", "project_id",
                                 "auth_test", http_log_debug=True)
-        self.assertEqual(len(cl2._logger.handlers), 1)
+        self.assertEqual(1, len(cl2._logger.handlers))
 
     @mock.patch.object(requests, 'request', unknown_error_mock_request)
     def test_unknown_server_error(self):
@@ -150,7 +176,37 @@ class ClientTest(utils.TestCase):
         # Python 2.7 and testtools doesn't match that implementation yet
         try:
             cl.get('/hi')
-        except exceptions.ServiceUnavailable as exc:
-            self.assertIn('Service Unavailable (HTTP 503)', six.text_type(exc))
+        except exceptions.ClientException as exc:
+            self.assertIn('Unknown Error', six.text_type(exc))
         else:
-            self.fail('Expected exceptions.ServiceUnavailable')
+            self.fail('Expected exceptions.ClientException')
+
+    @mock.patch.object(requests, "request", retry_after_mock_request)
+    def test_retry_after_request(self):
+        cl = get_client()
+
+        try:
+            cl.get("/hi")
+        except exceptions.OverLimit as exc:
+            self.assertEqual(5, exc.retry_after)
+        else:
+            self.fail('Expected exceptions.OverLimit')
+
+    @mock.patch.object(requests, "request",
+                       retry_after_no_headers_mock_request)
+    def test_retry_after_request_no_headers(self):
+        cl = get_client()
+
+        try:
+            cl.get("/hi")
+        except exceptions.OverLimit as exc:
+            self.assertEqual(0, exc.retry_after)
+        else:
+            self.fail('Expected exceptions.OverLimit')
+
+    @mock.patch.object(requests, "request",
+                       retry_after_non_supporting_mock_request)
+    def test_retry_after_request_non_supporting_exc(self):
+        cl = get_client()
+
+        self.assertRaises(exceptions.Forbidden, cl.get, "/hi")
