@@ -16,24 +16,26 @@
 
 import six
 
+from novaclient.tests.fixture_data import availability_zones as data
+from novaclient.tests.fixture_data import client
 from novaclient.tests import utils
-from novaclient.tests.v1_1 import fakes
 from novaclient.v1_1 import availability_zones
 
 
-class AvailabilityZoneTest(utils.TestCase):
+class AvailabilityZoneTest(utils.FixturedTestCase):
     # NOTE(cyeoh): import shell here so the V3 version of
     # this class can inherit off the v3 version of shell
     from novaclient.v1_1 import shell  # noqa
 
+    data_fixture_class = data.V1
+
+    scenarios = [('original', {'client_fixture_class': client.V1}),
+                 ('session', {'client_fixture_class': client.SessionV1})]
+
     def setUp(self):
         super(AvailabilityZoneTest, self).setUp()
-        self.cs = self._get_fake_client()
         self.availability_zone_type = self._get_availability_zone_type()
 
-    def _get_fake_client(self):
-        return fakes.FakeClient()
-
     def _get_availability_zone_type(self):
         return availability_zones.AvailabilityZone
 
@@ -43,7 +45,7 @@ class AvailabilityZoneTest(utils.TestCase):
 
     def test_list_availability_zone(self):
         zones = self.cs.availability_zones.list(detailed=False)
-        self.cs.assert_called('GET', '/os-availability-zone')
+        self.assert_called('GET', '/os-availability-zone')
 
         for zone in zones:
             self.assertIsInstance(zone, self.availability_zone_type)
@@ -56,14 +58,14 @@ class AvailabilityZoneTest(utils.TestCase):
         z0 = self.shell._treeizeAvailabilityZone(zones[0])
         z1 = self.shell._treeizeAvailabilityZone(zones[1])
 
-        self.assertEqual((len(z0), len(z1)), (1, 1))
+        self.assertEqual((1, 1), (len(z0), len(z1)))
 
         self._assertZone(z0[0], l0[0], l0[1])
         self._assertZone(z1[0], l1[0], l1[1])
 
     def test_detail_availability_zone(self):
         zones = self.cs.availability_zones.list(detailed=True)
-        self.cs.assert_called('GET', '/os-availability-zone/detail')
+        self.assert_called('GET', '/os-availability-zone/detail')
 
         for zone in zones:
             self.assertIsInstance(zone, self.availability_zone_type)
@@ -87,7 +89,7 @@ class AvailabilityZoneTest(utils.TestCase):
         z1 = self.shell._treeizeAvailabilityZone(zones[1])
         z2 = self.shell._treeizeAvailabilityZone(zones[2])
 
-        self.assertEqual((len(z0), len(z1), len(z2)), (3, 5, 1))
+        self.assertEqual((3, 5, 1), (len(z0), len(z1), len(z2)))
 
         self._assertZone(z0[0], l0[0], l0[1])
         self._assertZone(z0[1], l1[0], l1[1])
