@@ -11,30 +11,35 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import six
+
+from novaclient.tests.fixture_data import client
+from novaclient.tests.fixture_data import cloudpipe as data
 from novaclient.tests import utils
-from novaclient.tests.v1_1 import fakes
 from novaclient.v1_1 import cloudpipe
 
 
-cs = fakes.FakeClient()
+class CloudpipeTest(utils.FixturedTestCase):
 
+    data_fixture_class = data.Fixture
 
-class CloudpipeTest(utils.TestCase):
+    scenarios = [('original', {'client_fixture_class': client.V1}),
+                 ('session', {'client_fixture_class': client.SessionV1})]
 
     def test_list_cloudpipes(self):
-        cp = cs.cloudpipe.list()
-        cs.assert_called('GET', '/os-cloudpipe')
+        cp = self.cs.cloudpipe.list()
+        self.assert_called('GET', '/os-cloudpipe')
         [self.assertIsInstance(c, cloudpipe.Cloudpipe) for c in cp]
 
     def test_create(self):
         project = "test"
-        cp = cs.cloudpipe.create(project)
+        cp = self.cs.cloudpipe.create(project)
         body = {'cloudpipe': {'project_id': project}}
-        cs.assert_called('POST', '/os-cloudpipe', body)
-        self.assertIsInstance(cp, str)
+        self.assert_called('POST', '/os-cloudpipe', body)
+        self.assertIsInstance(cp, six.string_types)
 
     def test_update(self):
-        cs.cloudpipe.update("192.168.1.1", 2345)
+        self.cs.cloudpipe.update("192.168.1.1", 2345)
         body = {'configure_project': {'vpn_ip': "192.168.1.1",
                                       'vpn_port': 2345}}
-        cs.assert_called('PUT', '/os-cloudpipe/configure-project', body)
+        self.assert_called('PUT', '/os-cloudpipe/configure-project', body)
