@@ -656,7 +656,7 @@ class ShellTest(utils.TestCase):
                 'max_count': 1,
             }},
         )
-        self.assertEqual(poll_method.call_count, 1)
+        self.assertEqual(1, poll_method.call_count)
         poll_method.assert_has_calls(
             [mock.call(self.shell.cs.servers.get, 1234, 'building',
                        ['active'])])
@@ -857,7 +857,7 @@ class ShellTest(utils.TestCase):
 
     def test_rebuild(self):
         output = self.run_command('rebuild sample-server 1')
-        self.assert_called('GET', '/servers', pos=-6)
+        self.assert_called('GET', '/servers?name=sample-server', pos=-6)
         self.assert_called('GET', '/servers/1234', pos=-5)
         self.assert_called('GET', '/images/1', pos=-4)
         self.assert_called('POST', '/servers/1234/action',
@@ -869,7 +869,7 @@ class ShellTest(utils.TestCase):
     def test_rebuild_password(self):
         output = self.run_command('rebuild sample-server 1'
                                   ' --rebuild-password asdf')
-        self.assert_called('GET', '/servers', pos=-6)
+        self.assert_called('GET', '/servers?name=sample-server', pos=-6)
         self.assert_called('GET', '/servers/1234', pos=-5)
         self.assert_called('GET', '/images/1', pos=-4)
         self.assert_called('POST', '/servers/1234/action',
@@ -881,7 +881,7 @@ class ShellTest(utils.TestCase):
 
     def test_rebuild_preserve_ephemeral(self):
         self.run_command('rebuild sample-server 1 --preserve-ephemeral')
-        self.assert_called('GET', '/servers', pos=-6)
+        self.assert_called('GET', '/servers?name=sample-server', pos=-6)
         self.assert_called('GET', '/servers/1234', pos=-5)
         self.assert_called('GET', '/images/1', pos=-4)
         self.assert_called('POST', '/servers/1234/action',
@@ -893,7 +893,7 @@ class ShellTest(utils.TestCase):
     def test_rebuild_name_meta(self):
         self.run_command('rebuild sample-server 1 --name asdf --meta '
                          'foo=bar')
-        self.assert_called('GET', '/servers', pos=-6)
+        self.assert_called('GET', '/servers?name=sample-server', pos=-6)
         self.assert_called('GET', '/servers/1234', pos=-5)
         self.assert_called('GET', '/images/1', pos=-4)
         self.assert_called('POST', '/servers/1234/action',
@@ -1043,10 +1043,10 @@ class ShellTest(utils.TestCase):
         self.assert_called('DELETE', '/servers/1234', pos=-3)
         self.assert_called('DELETE', '/servers/5678', pos=-1)
         self.run_command('delete sample-server sample-server2')
-        self.assert_called('GET', '/servers', pos=-6)
+        self.assert_called('GET', '/servers?name=sample-server', pos=-6)
         self.assert_called('GET', '/servers/1234', pos=-5)
         self.assert_called('DELETE', '/servers/1234', pos=-4)
-        self.assert_called('GET', '/servers', pos=-3)
+        self.assert_called('GET', '/servers?name=sample-server2', pos=-3)
         self.assert_called('GET', '/servers/5678', pos=-2)
         self.assert_called('DELETE', '/servers/5678', pos=-1)
 
@@ -1683,7 +1683,8 @@ class ShellTest(utils.TestCase):
             '--instances', '--cores', '--ram', '--floating-ips', '--fixed-ips',
             '--metadata-items', '--injected-files',
             '--injected-file-content-bytes', '--injected-file-path-bytes',
-            '--key-pairs', '--security-groups', '--security-group-rules'
+            '--key-pairs', '--security-groups', '--security-group-rules',
+            '--server-groups', '--server-group-members'
         )
         for arg in args:
             self.run_command('quota-class-update '
@@ -1901,13 +1902,6 @@ class ShellTest(utils.TestCase):
                                {'name': 'test',
                                 'description': 'FAKE_SECURITY_GROUP'}})
 
-    def test_security_group_create_without_description(self):
-        self.run_command('secgroup-create test')
-        self.assert_called('POST', '/os-security-groups',
-                           {'security_group':
-                               {'name': 'test',
-                                'description': None}})
-
     def test_security_group_update(self):
         self.run_command('secgroup-update test te FAKE_SECURITY_GROUP')
         self.assert_called('PUT', '/os-security-groups/1',
@@ -2002,7 +1996,7 @@ class ShellTest(utils.TestCase):
 
     def test_volume_show(self):
         self.run_command('volume-show Work')
-        self.assert_called('GET', '/volumes', pos=-2)
+        self.assert_called('GET', '/volumes?name=Work', pos=-2)
         self.assert_called(
             'GET',
             '/volumes/15e59938-07d5-11e1-90e3-e3dffe0c5983',
@@ -2213,7 +2207,7 @@ class GetSecgroupTest(utils.TestCase):
             'security_groups.list.return_value': [],
         })
         result = novaclient.v1_1.shell._get_secgroup(cs, '1')
-        self.assertEqual(result, 'sec_group')
+        self.assertEqual('sec_group', result)
         cs.security_groups.get.assert_called_once_with('1')
 
     def test_with_uuid(self):
@@ -2223,7 +2217,7 @@ class GetSecgroupTest(utils.TestCase):
         })
         result = novaclient.v1_1.shell._get_secgroup(
             cs, 'c0c32459-dc5f-44dc-9a0a-473b28bac831')
-        self.assertEqual(result, 'sec_group')
+        self.assertEqual('sec_group', result)
         cs.security_groups.get.assert_called_once_with(
             'c0c32459-dc5f-44dc-9a0a-473b28bac831')
 
