@@ -247,7 +247,7 @@ class ShellTest(utils.TestCase):
                 'image_ref': '1',
                 'os-multiple-create:min_count': 1,
                 'os-multiple-create:max_count': 1,
-                'os-user-data:user_data': user_data}},
+                'user_data': user_data}},
         )
 
     def test_boot_avzone(self):
@@ -273,8 +273,8 @@ class ShellTest(utils.TestCase):
         self.assert_called_anytime(
             'POST', '/servers',
             {'server': {
-                'os-security-groups:security_groups': [{'name': 'secgroup1'},
-                                                       {'name': 'secgroup2'}],
+                'security_groups': [{'name': 'secgroup1'},
+                                    {'name': 'secgroup2'}],
                 'flavor_ref': '1',
                 'name': 'some-server',
                 'image_ref': '1',
@@ -337,7 +337,7 @@ class ShellTest(utils.TestCase):
             {'server': {
                 'flavor_ref': '1',
                 'name': 'some-server',
-                'os-block-device-mapping:block_device_mapping': [
+                'block_device_mapping': [
                     {
                         'volume_id': 'blah',
                         'delete_on_termination': '0',
@@ -366,7 +366,7 @@ class ShellTest(utils.TestCase):
             {'server': {
                 'flavor_ref': '1',
                 'name': 'some-server',
-                'os-block-device-mapping:block_device_mapping': [
+                'block_device_mapping': [
                     {'device_name': 'id', 'volume_id': id,
                      'source_type': 'volume', 'boot_index': 0, 'uuid': id}],
                 'image_ref': '1',
@@ -566,7 +566,7 @@ class ShellTest(utils.TestCase):
                 'os-multiple-create:max_count': 1,
             }},
         )
-        self.assertEqual(poll_method.call_count, 1)
+        self.assertEqual(1, poll_method.call_count)
         poll_method.assert_has_calls(
             [mock.call(self.shell.cs.servers.get, 1234, 'building',
                        ['active'])])
@@ -655,10 +655,10 @@ class ShellTest(utils.TestCase):
         self.assert_called('DELETE', '/servers/1234', pos=-3)
         self.assert_called('DELETE', '/servers/5678', pos=-1)
         self.run_command('delete sample-server sample-server2')
-        self.assert_called('GET', '/servers', pos=-6)
+        self.assert_called('GET', '/servers?name=sample-server', pos=-6)
         self.assert_called('GET', '/servers/1234', pos=-5)
         self.assert_called('DELETE', '/servers/1234', pos=-4)
-        self.assert_called('GET', '/servers', pos=-3)
+        self.assert_called('GET', '/servers?name=sample-server2', pos=-3)
         self.assert_called('GET', '/servers/5678', pos=-2)
         self.assert_called('DELETE', '/servers/5678', pos=-1)
 
