@@ -405,7 +405,7 @@ class ServerManager(base.BootingManagerWithFind):
                 userdata = encodeutils.safe_encode(userdata)
 
             data = base64.b64encode(userdata).decode('utf-8')
-            body["server"]["os-user-data:user_data"] = data
+            body["server"]["user_data"] = data
         if meta:
             body["server"]["metadata"] = meta
         if reservation_id:
@@ -428,7 +428,7 @@ class ServerManager(base.BootingManagerWithFind):
         body["server"]["os-multiple-create:max_count"] = max_count
 
         if security_groups:
-            body["server"]["os-security-groups:security_groups"] = \
+            body["server"]["security_groups"] = \
               [{'name': sg} for sg in security_groups]
 
         if availability_zone:
@@ -437,11 +437,12 @@ class ServerManager(base.BootingManagerWithFind):
 
         # Block device mappings are passed as a list of dictionaries
         if block_device_mapping:
-            bdm_param = 'os-block-device-mapping:block_device_mapping'
+            bdm_param = 'block_device_mapping'
             body['server'][bdm_param] = \
               self._parse_block_device_mapping(block_device_mapping)
         elif block_device_mapping_v2:
             # Append the image to the list only if we have new style BDMs
+            bdm_param = 'block_device_mapping_v2'
             if image:
                 bdm_dict = {'uuid': image.id, 'source_type': 'image',
                             'destination_type': 'local', 'boot_index': 0,
